"""
    Describe what we need to do before commit is complete
"""


from pathlib import Path
from sftp_uploader.services.applications.sftp_uploader import update_files

from sftp_uploader.services.exceptions.pre_commit_actions import CannotActivatePythonVenv


def setup_env():
    activate_this_script = 'venv/bin/activate_this.py'

    if Path(activate_this_script).absolute().exists():
        exec(open(activate_this_script).read(),
             {'__file__': activate_this_script})
    else:
        raise CannotActivatePythonVenv


def pre_commit_actions():
    setup_env()
    update_files()





GIT_IGNORE_FILENAME = '.gitignore'


# GIT_HOOK_SCRIPT_TO_UPLOAD = """
# #!/bin/sh
#
# handle_exception() {
#     arch -arm64 python main.py
# }
#
# trap handle_exception ERR
#
# python main.py
# """

GIT_HOOK_SCRIPT_TO_UPLOAD = """#!/bin/sh

handle_exception() {
    arch -arm64 python -c "import sftp_uploader; sftp_uploader.pre_commit_actions()"
}

trap handle_exception ERR

python -c "import sftp_uploader; sftp_uploader.pre_commit_actions()"

exit 0
"""



GIT_HOOKS_FOLDER = '.git/hooks/'
GIT_HOOK_PRECOMMIT_FILE = f'{GIT_HOOKS_FOLDER}pre-commit'
